import logging

from . import exceptions
from ._ldaps import _search, LdapObject

logger = logging.getLogger(__name__)


def _get_domain_root_attribute(connection: LdapObject, *, attribute: str):
    logger.debug(f"getting domain root attribute {attribute}")
    try:
        # We can get domain root attributes from Active Directory by querying the base
        # distinguishedName of the domain - https://ldapwiki.com/wiki/Domain%20root%20object
        return next(iter(_search(connection, f"(distinguishedName={connection._base_dn})")))[attribute][0]
    except StopIteration:
        raise exceptions.NoSuchObject(
            f"Could not retrieve the domain root object using distinguishedName '{connection._base_dn}'."
        )
    except (KeyError, IndexError):
        raise exceptions.NoSuchObject(f"The domain root object does not contain the {attribute} attribute.")
